Validation of Assay5 objects is handled by validObject

Layer Validation

blah

Key Validation

Keys must be a one-length character vector; a key must be composed of one of the following:

  • An empty string (eg. “''”) where nchar() == 0

  • An string composed of one or more alphanumeric values (both lower- and upper-case) that ends with an underscore (“_”); the first character must be a letter

Keys that are not empty strings are validated with the regex “^[a-zA-Z][a-zA-Z0-9]*_$