Subset an Assay

# S3 method for class 'Assay5'
subset(x, cells = NULL, features = NULL, layers = NULL, ...)

Arguments

x

An Assay5 object

cells

Cell names

features

Feature names

layers

Layer to keep; defaults to all layers

...

Ignored

Value

x with just the cells and features specified by cells and features for the layers specified by layers

See also